/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#include "facetsettingsmodel.h"

FacetSettingsModel::FacetSettingsModel(QStringList total, QStringList selected, QObject* parent): QAbstractListModel(parent)
{
    foreach (QString s, total) {
        facets.insert(s, false);
    }
    foreach (QString s, selected) {
        if (facets.keys().contains(s)) {
            facets.insert(s, true);
        }
    }
}

FacetSettingsModel::~FacetSettingsModel()
{
}

int FacetSettingsModel::rowCount(const QModelIndex& parent) const
{
    Q_UNUSED(parent);

    return facets.size();
}

QVariant FacetSettingsModel::data(const QModelIndex& index, int role) const
{
    if (index.row() < rowCount() && index.column() == 0)
    {
        if (role == Qt::DisplayRole) {
            return QVariant(facets.keys()[index.row()]);
        }
        if (role == Qt::CheckStateRole) {
            return QVariant(facets.value(facets.keys()[index.row()]) ? Qt::Checked : Qt::Unchecked);
        }
    }
    return QVariant();
}

Qt::ItemFlags FacetSettingsModel::flags(const QModelIndex& index) const
{
    if (index.isValid()) {
        return Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
    }
    else {
        return Qt::NoItemFlags;
    }
}

bool FacetSettingsModel::setData(const QModelIndex& index, const QVariant& value, int role)
{
    if (index.row() < rowCount() && index.column() == 0)
    {
        if (role == Qt::CheckStateRole) {
            if (value.toInt() == Qt::Checked) {
                facets.insert(facets.keys()[index.row()], true);
            }
            else {
                facets.insert(facets.keys()[index.row()], false);
            }
            QStringList selected = facets.keys(true);
            emit facetSelectionChanged(selected);
            emit dataChanged(index, index);

            return true;
        }
    }

    return false;
}

#include "facetsettingsmodel.moc"
