/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#include <QButtonGroup>
#include <QVBoxLayout>
#include <QSizePolicy>
#include <QGridLayout>
#include <QList>

#include <Soprano/LiteralValue>
#include <Nepomuk/Query/AndTerm>
#include <Nepomuk/Query/ComparisonTerm>
#include <Nepomuk/Query/LiteralTerm>
#include <Nepomuk/Types/Property>

#include "datefacet.h"
#include "daterangeselectionwidget.h"
#include "nie.h"
#include "datetoolbutton.h"

using namespace Nepomuk;

class DateFacet::Private
{
    public:
        Private(): any(0)
        {
        }
        ~Private()
        {
        }
        QToolButton* any;
        Query::Term queryTerm;
};

DateFacet::DateFacet(QWidget* parent): Facet(parent), d(new Private())
{
    setupUi(this);
    m_facetBox->setTitle("When?");
    // moreButton->setEnabled(true);
    connect(moreButton, SIGNAL(clicked(bool)), this, SLOT(startDateWidget()));
    QButtonGroup* group = new QButtonGroup(this);
    connect(group, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(dateChanged(QAbstractButton*)));

    QSizePolicy policy(QSizePolicy::Expanding, QSizePolicy::Minimum);
    DateToolButton* b1 = new DateToolButton(this);
    b1->setText(i18n("Anytime"));
    b1->setPeriod(DateToolButton::Anytime);
    b1->setCheckable(true);
    b1->setChecked(true);
    b1->setSizePolicy(policy);
    b1->setAutoRaise(true);
    group->addButton(b1);
    m_scrollLayout->addWidget(b1, 0, 0);
    d->any = b1;
    DateToolButton* b2 = new DateToolButton(this);
    b2->setText(i18n("Today"));
    b2->setPeriod(DateToolButton::Today);
    b2->setCheckable(true);
    b2->setSizePolicy(policy);
    b2->setAutoRaise(true);
    group->addButton(b2);
    m_scrollLayout->addWidget(b2, 1, 0);
    DateToolButton* b3 = new DateToolButton(this);
    b3->setText(i18n("Yesterday"));
    b3->setPeriod(DateToolButton::Yesterday);
    b3->setCheckable(true);
    b3->setSizePolicy(policy);
    b3->setAutoRaise(true);
    group->addButton(b3);
    m_scrollLayout->addWidget(b3, 2, 0);
    DateToolButton* b4 = new DateToolButton(this);
    b4->setText(i18n("This week"));
    b4->setPeriod(DateToolButton::ThisWeek);
    b4->setCheckable(true);
    b4->setSizePolicy(policy);
    b4->setAutoRaise(true);
    group->addButton(b4);
    m_scrollLayout->addWidget(b4, 3, 0);
    DateToolButton* b5 = new DateToolButton(this);
    b5->setText(i18n("This month"));
    b5->setPeriod(DateToolButton::ThisMonth);
    b5->setCheckable(true);
    b5->setSizePolicy(policy);
    b5->setAutoRaise(true);
    group->addButton(b5);
    m_scrollLayout->addWidget(b5, 4, 0);
}

DateFacet::~DateFacet()
{
    delete d;
}

void DateFacet::startDateWidget()
{
    /*DateRangeSelectionWidget* dateBox = new DateRangeSelectionWidget();
    connect(dateBox, SIGNAL(lessButtonClicked(bool)), this, SLOT(switchWidget()));
    connect(dateBox, SIGNAL(rangeChanged(const DateRange&)), this, SLOT(dateChanged(const DateRange&)));*/
}

void DateFacet::doFolderChanged(const QString& folder)
{
    Q_UNUSED(folder);
    d->any->setChecked(true);
}

void DateFacet::dateChanged(const DateRange& range)
{
    Query::AndTerm term;
    Query::ComparisonTerm cterm1(
            Types::Property(Vocabulary::NIE::lastModified()),
            Query::LiteralTerm(Soprano::LiteralValue(range.start())),
            Query::ComparisonTerm::GreaterOrEqual);
    Query::ComparisonTerm cterm2(
            Types::Property(Vocabulary::NIE::lastModified()),
            Query::LiteralTerm(Soprano::LiteralValue(range.end())),
            Query::ComparisonTerm::SmallerOrEqual);
    term.addSubTerm(cterm1);
    term.addSubTerm(cterm2);
    d->queryTerm = term;
    emit queryTermChanged(d->queryTerm);
}

void DateFacet::dateChanged(QAbstractButton* button)
{
    DateToolButton* b = qobject_cast<DateToolButton*>(button);
    switch (b->getPeriod()) {
        case DateToolButton::Anytime:
            // send and invalid term: the date query part is gone
            d->queryTerm = Query::Term();
            emit queryTermChanged(d->queryTerm);
            break;
        case DateToolButton::Today:
            dateChanged(DateRange::today());
            break;
        case DateToolButton::Yesterday:
            dateChanged(DateRange::yesterday());
            break;
        case DateToolButton::ThisWeek:
            dateChanged(DateRange::thisWeek());
            break;
        case DateToolButton::ThisMonth:
            dateChanged(DateRange::thisMonth());
            break;
        default:
            // not used
            break;
    }
}

Nepomuk::Query::Term DateFacet::currentQueryTerm() const
{
    return d->queryTerm;
}

bool DateFacet::currentQueryTermValidation() const
{
    return d->queryTerm.isValid();
}

#include "datefacet.moc"
