/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#include <KDebug>

#include "facetfilterproxysortmodel.h"
#include "facetmodel.h"

FacetFilterProxySortModel::FacetFilterProxySortModel(QObject* parent): QSortFilterProxyModel(parent)
{
}

FacetFilterProxySortModel::~FacetFilterProxySortModel()
{
}

/**
 * The following order is created by this method:
 * - checked nodes
 *   - frequency high-to-low
 *     - alphabet ASC
 * - non-checked nodes
 *   - frequency high-to-low
 *     - alphabet ASC
 *
 * In this way, all checked elements are before the non-checked ones,
 * in each group the nodes with higher frequency are before the lower
 * ones, and finally between same state and same frequency, standard
 * alphabet ordering is applied.
 */
bool FacetFilterProxySortModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
{
    QString leftString = left.data(Qt::DisplayRole).toString();
    QString rightString = right.data(Qt::DisplayRole).toString();
    int leftState = left.data(Qt::CheckStateRole).toInt();
    int rightState = right.data(Qt::CheckStateRole).toInt();
    int leftFreq = left.data(FacetModel::FrequencyRole).toInt();
    int rightFreq = right.data(FacetModel::FrequencyRole).toInt();

    if (leftState < rightState) {
        return false;
    }
    else if (leftState > rightState) {
        return true;
    }
    else {
        if (leftFreq < rightFreq) {
            return false;
        }
        else if (leftFreq > rightFreq) {
            return true;
        }
        else {
            return leftString < rightString;
        }
    }
}

bool FacetFilterProxySortModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
{
    FacetModel* model = qobject_cast<FacetModel*>(sourceModel());
    QModelIndex row = model->index(sourceRow, 0, sourceParent);
    int min = model->minCount();
    int count = row.data(FacetModel::CountRole).toInt();
    bool checked = row.data(Qt::CheckStateRole).toInt() == Qt::Checked;
    if (count == 0 || (count == min && !checked)) {
        return false;
    }

    return true;
}

#include "facetfilterproxysortmodel.moc"
