/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#ifndef FACETMODEL_H_
#define FACETMODEL_H_

#include <QAbstractListModel>
#include <QModelIndex>
#include <QVariant>

class FacetModel : public QAbstractListModel
{
    Q_OBJECT

    public:
        FacetModel(QObject* parent = 0);
        virtual ~FacetModel();

        int rowCount(const QModelIndex& parent = QModelIndex()) const;
        QVariant data(const QModelIndex& index, int role) const;
        Qt::ItemFlags flags(const QModelIndex& index) const;
        bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
        bool contains(const QString& tag) const;
        int minCount() const;

        enum CustomRoles {
            CountRole = 475648,
            FrequencyRole = 534323
        };

    public Q_SLOTS:
        void addNewItem(const QString& name, const int count);
        void updateFrequency(const QString& label, const int frequency);
        void clear();

    Q_SIGNALS:
        void itemChecked(const QString& label);
        void itemUnchecked(const QString& label);

    private:
        class Private;
        Private* d;
};

#endif /* FACETMODEL_H_ */
