/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */

#include "term.h"

class Term::Private
{
    public:
        Private(const QString& n, const int c, const int f): name(n), count(c), frequency(f), checked(false)
        {
        }
        QString name;
        int count;
        int frequency;
        bool checked;
};

Term::Term(const QString& name, const int count, const int frequency, QObject* parent): QObject(parent), d(new Private(name, count, frequency))
{
}

Term::Term(const Term& other): QObject(other.parent()), d(new Private(other.getName(), other.getCount(), other.getFrequency()))
{
    d->checked = other.isChecked();
}

Term::~Term()
{
    delete d;
}

void Term::setName(const QString& n)
{
    d->name = n;
}

QString Term::getName() const
{
    return d->name;
}

void Term::setCount(const int count)
{
    d->count = count;
}

int Term::getCount() const
{
    return d->count;
}

void Term::setChecked(bool checked)
{
    d->checked = checked;
}

bool Term::isChecked() const
{
    return d->checked;
}

void Term::setFrequency(const int frequency)
{
    d->frequency = frequency;
}

int Term::getFrequency() const
{
    return d->frequency;
}

bool Term::operator==(const Term& other)
{
    // only names matter
    if (other.getName() == d->name) {
        return true;
    }

    return false;
}

Term &Term::operator=(const Term& other)
{
    d->name = other.getName();
    d->count = other.getCount();
    d->frequency = other.getFrequency();
    d->checked = other.isChecked();
    setParent(other.parent());

    return *this;
}

#include "term.moc"
