/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#ifndef TAB_H
#define TAB_H

#include <QWidget>
#include <QModelIndex>

#include <KUrl>
#include <KFile>
#include <KFileItem>

class Tab : public QWidget
{
    Q_OBJECT

    public:
        Tab();
        virtual ~Tab();

        void setAddress(const KUrl& address);
        KUrl address();
        void setMode(KFile::FileView mode);
        KFile::FileView mode();
        void saveState();
        void loadState();
        void cutCurrentSelection();
        void copyCurrentSelection();
        void paste();

    public Q_SLOTS:
        void back();
        void forward();
        void home();
        void fileSelected(const KFileItem& item);
        void dirActivated(const QModelIndex& index);
        void redisplay();
        void setIconsView();
        void setDetailedView();
        void selectAll();
        void deselect();

    Q_SIGNALS:
        void dirChanged(const KUrl& url);
        void dirChanged(const QString& url);

    private:
        QMimeData* getSelectedMime() const;
        
        class Private;
        Private* d;
};

#endif // TAB_H
